@@ -105,20 +105,20 @@ class order:
             else:
                 position = {
                     'code': bidask['code'],
-                    'direction': last_trade['action'],
+                    'direction': last_trade['action'].to_string(index=False),
                     'quantity': 1,
-                    'price': last_trade['price'],
+                    'price': last_trade['price'].sum(),
                 }
                 if ((last_trade['action'] == 'Buy').bool()):
                     position['last_price'] = bidask['ask_price'][0]
-                    position['pnl'] = (bidask['ask_price'][0] - last_trade['price']) * 200 - last_trade['fee'] - \
+                    position['pnl'] = ((bidask['ask_price'][0] - last_trade['price']) * 200 - last_trade['fee'] - \
                         last_trade['tax'] - 50 - \
-                        round(bidask['ask_price'][0] * 200 * 2 / 100000)
+                        round(bidask['ask_price'][0] * 200 * 2 / 100000)).sum()
                 else:
                     position['last_price'] = bidask['bid_price'][0]
-                    position['pnl'] = (last_trade['price'] - bidask['bid_price'][0]) * 200 - last_trade['fee'] - \
+                    position['pnl'] = ((last_trade['price'] - bidask['bid_price'][0]) * 200 - last_trade['fee'] - \
                         last_trade['tax'] - 50 - \
-                        round(bidask['bid_price'][0] * 200 * 2 / 100000)
+                        round(bidask['bid_price'][0] * 200 * 2 / 100000)).sum()
                 return position
         else:
             return []
